==> xlr-webhooks-module-23.3.8-sources.jar: com/xebialabs/xlrelease/webhooks/consumers/jython/CustomJythonEventSourceHandler.scala <==
package com.xebialabs.xlrelease.webhooks.consumers.jython

import com.xebialabs.deployit.plugin.api.reflect.Type
import com.xebialabs.platform.script.jython.ScriptSource
import com.xebialabs.xlplatform.webhooks.events.domain.Event
import com.xebialabs.xlplatform.webhooks.events.handlers.EventProcessorHandler
import com.xebialabs.xlplatform.webhooks.queue.JmsEventPublisherHandler
import com.xebialabs.xlrelease.config.TypedWebhookFeatureToggleCondition
import com.xebialabs.xlrelease.webhooks.consumers.BaseConsumerHandler
import com.xebialabs.xlrelease.webhooks.utils.JythonScriptEventProcessingUtils
import grizzled.slf4j.Logging
import org.springframework.beans.factory.annotation.{Autowired, Value}
import org.springframework.context.annotation.Conditional
import org.springframework.jms.core.JmsTemplate
import org.springframework.stereotype.Component
import org.springframework.util.ResourceUtils

import java.io.FileNotFoundException
import scala.util.Try


@Component
@Conditional(value = Array(classOf[TypedWebhookFeatureToggleCondition]))
class CustomJythonEventSourceHandler @Autowired()(val jmsTemplate: JmsTemplate,
                                                  @Value("${xl.queue.queueName}") val queueName: String,
                                                  jythonScriptUtils: JythonScriptEventProcessingUtils)
  extends EventProcessorHandler[Event, Event, CustomJythonEventSource]
    with JmsEventPublisherHandler[Event, CustomJythonEventSource]
    with BaseConsumerHandler[CustomJythonEventSource]
    with Logging {

  import jythonScriptUtils._

  def consumerConfigType: Type = Type.valueOf(classOf[CustomJythonEventSource])

  override def filter(config: CustomJythonEventSource, event: Event): Boolean = {
    nonEmptyScriptLocation(config.filterScriptLocation).forall { path =>
      Try(ResourceUtils.getFile(path)).map { _ =>
        executeFilter(config, event, sandbox = false)
          .apply(logger)
          .apply(ScriptSource.byResource(path))
      }.recover {
        case e: FileNotFoundException =>
          logger.error("Filter caused exception, assuming false", e)
          false
      }.get
    }

  }

  override def map(config: CustomJythonEventSource, event: Event): Event = {
    val scriptSource = ScriptSource.byResource(scriptLocationOrDefault(config.getType, config.scriptLocation))
    executeMap(config, event, sandbox = false)
      .apply(logger)
      .apply(scriptSource)
  }
}

==> xlr-webhooks-module-25.1.0-1212.113-sources.jar: com/xebialabs/xlrelease/webhooks/consumers/jython/CustomJythonEventSourceHandler.scala <==
package com.xebialabs.xlrelease.webhooks.consumers.jython

import com.xebialabs.deployit.plugin.api.reflect.Type
import com.xebialabs.platform.script.jython.ScriptSource
import com.xebialabs.xlplatform.webhooks.events.domain.Event
import com.xebialabs.xlplatform.webhooks.events.handlers.EventProcessorHandler
import com.xebialabs.xlrelease.config.TypedWebhookFeatureToggleCondition
import com.xebialabs.xlrelease.webhooks.consumers.BaseConsumerHandler
import com.xebialabs.xlrelease.webhooks.jms.JmsEventPublisherHandler
import com.xebialabs.xlrelease.webhooks.utils.JythonScriptEventProcessingUtils
import grizzled.slf4j.Logging
import org.springframework.context.annotation.Conditional
import org.springframework.jms.core.JmsTemplate
import org.springframework.stereotype.Component
import org.springframework.util.ResourceUtils

import java.io.FileNotFoundException
import scala.util.Try


@Component
@Conditional(value = Array(classOf[TypedWebhookFeatureToggleCondition]))
class CustomJythonEventSourceHandler(val jmsTemplate: JmsTemplate,
                                     jythonScriptUtils: JythonScriptEventProcessingUtils)
  extends EventProcessorHandler[Event, Event, CustomJythonEventSource]
    with JmsEventPublisherHandler[Event, CustomJythonEventSource]
    with BaseConsumerHandler[CustomJythonEventSource]
    with Logging {

  import jythonScriptUtils._

  def consumerConfigType: Type = Type.valueOf(classOf[CustomJythonEventSource])

  override def filter(config: CustomJythonEventSource, event: Event): Boolean = {
    nonEmptyScriptLocation(config.filterScriptLocation).forall { path =>
      Try(ResourceUtils.getFile(path)).map { _ =>
        executeFilter(config, event, sandbox = false)
          .apply(logger)
          .apply(ScriptSource.byResource(path))
      }.recover {
        case e: FileNotFoundException =>
          logger.error("Filter caused exception, assuming false", e)
          false
      }.get
    }

  }

  override def map(config: CustomJythonEventSource, event: Event): Event = {
    val scriptSource = ScriptSource.byResource(scriptLocationOrDefault(config.getType, config.scriptLocation))
    executeMap(config, event, sandbox = false)
      .apply(logger)
      .apply(scriptSource)
  }
}
